@@ -161,7 +161,7 @@ def random_color() -> str:
     -------
     str
         random rgb color, colors ranging between 0 and 255
-    
+
     Example
     -------
         rgb(127, 1, 36)
@@ -477,7 +477,7 @@ class Connector:
         '''
         self.data = {}
 
-    def sleep(self, seconds=0) -> None:
+    def sleep(self, seconds: float = 0) -> None:
         '''
         Sleep for the requested amount of time using the appropriate async model.
 
